@@ -11,13 +11,24 @@ from plone.registry.interfaces import IRegistry
 from collective.flexitopic.interfaces import IFlexiTopicSettings
 from collective.flexitopic import flexitopicMessageFactory as _
 from utils import get_search_results, get_topic_table_fields
-from utils import IDX_METADATA, get_start_end, get_renderd_table
+from utils import IDX_METADATA, DATERANGE_OPERATORS
+from utils import get_start_end, get_renderd_table
+from utils import get_search_results_ng, get_start_end_ng
+
+try:
+    from plone.app.querystring import queryparser
+    from plone.app.querystring.registryreader import QuerystringRegistryReader
+except ImportError:
+    pass
 
 KEYWORD_DELIMITER = ':'
 DATE_FIELD_WIDTH = 80
 FG_PADDING_WIDTH = 5
 
 
+
+
+
 class BaseViewlet(base.ViewletBase):
     ''' a common base for the viewlets used here '''
 
@@ -58,69 +69,9 @@ class SubtopicViewlet(BaseViewlet):
         return stl
 
 class FormViewlet(BaseViewlet):
-    ''' displays the query form'''
+    ''' displays the query form for old style collections'''
 
-    @property
-    def portal_catalog(self):
-        return getToolByName(self.context, 'portal_catalog')
-
-    def _get_calculate_js(self, start_date):
-        js_ctemplate = '''
-                calculate: function( value ){
-                    var start_date = new Date('%(start)s');
-                    var the_date = datesliderhelper.add_date(start_date, value);
-                    return datesliderhelper.format_date(the_date);
-                }'''
-        return js_ctemplate % { 'start': start_date.strftime('%Y/%m/%d')}
-
-    def _get_callback_js(self, name, start_date):
-        js_cbtemplate = '''
-                callback: function( value ){
-                    var values = value.split(';');
-                    var start_date = new Date('%(start)s');
-                    var start = datesliderhelper.add_date(start_date, values[0]);
-                    var end = datesliderhelper.add_date(start_date, values[1]);
-                    $('#start-search-%(name)s').val(datesliderhelper.format_date(start));
-                    $('#end-search-%(name)s').val(datesliderhelper.format_date(end));
-                    $('#flexitopicresults').flexOptions({newp: 1}).flexReload();
-                }'''
-        return js_cbtemplate % { 'start': start_date.strftime('%Y/%m/%d'),
-                                 'name': name
-                                }
-
-
-    def _sel(self, item, selected):
-        if item == selected:
-            return 'selected="selected"'
-        else:
-            return ''
-
-    def _get_index_values(self, idx):
-        items = list(self.portal_catalog.Indexes[
-                idx].uniqueValues())
-        selected = self.request.get(idx,None)
-        items.sort()
-        item_list =  [{'name': _('All'), 'value':'',
-                'disabled':None,
-                'selected':self._sel(None,selected)}]
-        for item in items:
-            item_list.append({'name': item, 'value':item,
-                    'disabled': None,
-                    'selected':self._sel(item,selected)})
-        return item_list
-
-
-    def get_criteria(self):
-        ''' combine request with topic criteria '''
-        def daterange_criterion(criterion):
-            date_diff = int(end_date - start_date) + 1
-            i_start = int(DateTime(startval) - start_date)
-            i_end = int(DateTime(endval) - start_date)
-            valrange = '%i;%i' % (i_start, i_end)
-            calc_template = self._get_calculate_js(start_date)
-            cb_template = self._get_callback_js(criterion.Field(),
-                        start_date)
-            return '''
+    jslider_template = u'''
                 <span id="search-%(id)s">
                     <input type=text"
                         size="10"
@@ -149,16 +100,79 @@ class FormViewlet(BaseViewlet):
                     </script>
 
                 </span>
-            ''' % { 'id': criterion.Field(),
-                    'name': criterion.Field(),
-                    'startval' : startval,
-                    'endval': endval,
-                    'valrange': valrange,
-                    'to': date_diff,
-                    'calculate': calc_template,
-                    'callback': cb_template}
+            '''
+
+    @property
+    def portal_catalog(self):
+        return getToolByName(self.context, 'portal_catalog')
+
+    def _get_calculate_js(self, start_date):
+        js_ctemplate = u'''
+                calculate: function( value ){
+                    var start_date = new Date('%(start)s');
+                    var the_date = datesliderhelper.add_date(start_date, value);
+                    return datesliderhelper.format_date(the_date);
+                }'''
+        return js_ctemplate % { 'start': start_date.strftime('%Y/%m/%d')}
+
+    def _get_callback_js(self, name, start_date):
+        js_cbtemplate = u'''
+                callback: function( value ){
+                    var values = value.split(';');
+                    var start_date = new Date('%(start)s');
+                    var start = datesliderhelper.add_date(start_date, values[0]);
+                    var end = datesliderhelper.add_date(start_date, values[1]);
+                    $('#start-search-%(name)s').val(datesliderhelper.format_date(start));
+                    $('#end-search-%(name)s').val(datesliderhelper.format_date(end));
+                    $('#flexitopicresults').flexOptions({newp: 1}).flexReload();
+                }'''
+        return js_cbtemplate % { 'start': start_date.strftime('%Y/%m/%d'),
+                                 'name': name
+                                }
 
 
+    def _sel(self, item, selected):
+        if item == selected:
+            return u'selected="selected"'
+        else:
+            return u''
+
+    def _get_index_values(self, idx):
+        items = list(self.portal_catalog.Indexes[
+                idx].uniqueValues())
+        selected = self.request.get(idx,None)
+        items.sort()
+        item_list =  [{u'name': _(u'All'), u'value':u'',
+                u'disabled':None,
+                u'selected':self._sel(None,selected)}]
+        for item in items:
+            item_list.append({u'name': item.decode('utf-8'),
+                    u'value':item.decode('utf-8'),
+                    u'disabled': None,
+                    u'selected':self._sel(item,selected)})
+        return item_list
+
+
+    def _daterange_criterion(self, field_name, start_date, form_start, end_date, form_end):
+        date_diff = int(end_date - start_date) + 1
+        i_start = int(DateTime(form_start) - start_date)
+        i_end = int(DateTime(form_end) - start_date)
+        valrange = u'%i;%i' % (i_start, i_end)
+        calc_template = self._get_calculate_js(start_date)
+        cb_template = self._get_callback_js(field_name,
+                    start_date)
+        return  self.jslider_template % {
+                'id': field_name,
+                'name': field_name,
+                'startval' : form_start,
+                'endval': form_end,
+                'valrange': valrange,
+                'to': date_diff,
+                'calculate': calc_template,
+                'callback': cb_template}
+
+    def get_criteria(self):
+        ''' combine request with topic criteria '''
         criteria = []
         portal_atct = getToolByName(self.context,'portal_atct')
         for criterion in self.context.listCriteria():
@@ -174,7 +188,7 @@ class FormViewlet(BaseViewlet):
                     }
                 if criterion.meta_type=='ATSimpleStringCriterion':
                     value = self.request.get(criterion.Field(),'')
-                    criterion_field['input'] = '''<input type="text"
+                    criterion_field['input'] = u'''<input type="text"
                             size="25"
                             name="%s"
                             id="search-%s"
@@ -183,9 +197,9 @@ class FormViewlet(BaseViewlet):
                 elif criterion.meta_type in ['ATSelectionCriterion',
                                             'ATListCriterion']:
                     options = u''
-                    if criterion.Field() == 'review_state':
-                        continue
                     if criterion.Value():
+                        if len(criterion.Value()) ==1:
+                            continue
                         selected = self.request.get(criterion.Field(),None)
                         if criterion.getOperator()=='or':
                             # we let the user choose from the selected
@@ -206,7 +220,7 @@ class FormViewlet(BaseViewlet):
                                     'value': idx_value,
                                     'selected': is_selected,
                                     'name': idx_name}
-                            criterion_field['input'] = '''
+                            criterion_field['input'] = u'''
                                     <select id="%s" name="%s">
                                     %s
                                     </select>''' % ( criterion.Field(),
@@ -222,7 +236,7 @@ class FormViewlet(BaseViewlet):
                                     continue
                                 else:
                                     options += u'<option value="%(value)s" %(selected)s >%(name)s</option>' % idx_value
-                            criterion_field['input'] = '''
+                            criterion_field['input'] = u'''
                                 <select id="%s" name="%s">
                                 %s
                                 </select>''' % ( criterion.Field(),
@@ -234,7 +248,7 @@ class FormViewlet(BaseViewlet):
                         idx_values = self._get_index_values(criterion.Field())
                         for idx_value in idx_values:
                             options += u'<option value="%(value)s" %(selected)s >%(name)s</option>' % idx_value
-                        criterion_field['input'] = '''
+                        criterion_field['input'] = u'''
                             <select id="%s" name="%s">
                             %s
                             </select>''' % ( criterion.Field(),
@@ -251,13 +265,104 @@ class FormViewlet(BaseViewlet):
                     endval = self.request.get('end-' + criterion.Field(),
                             end_date.strftime('%Y/%m/%d'))
 
-                    criterion_field['input'] = daterange_criterion(criterion)
+                    criterion_field['input'] = self._daterange_criterion(
+                        criterion.Field(), start_date, startval,
+                        end_date, endval)
+
+                    #criterion_field['input'] = daterange_criterion(criterion)
                 else:
                     criterion_field['input'] = None
                 criteria.append(criterion_field)
         return criteria
 
 
+class FormViewletNG(FormViewlet):
+    ''' displays the query form for new style collections'''
+
+    def get_criteria(self):
+        ''' combine request with topic criteria '''
+        criteria = []
+        query = queryparser.parseFormquery(self.context, self.context.getRawQuery())
+        registry = getUtility(IRegistry)
+        qsrr = QuerystringRegistryReader(registry)
+        for raw_query in self.context.getRawQuery():
+            criterion = qsrr()['indexes'][raw_query['i']]
+            input_html = ''
+            selected = self.request.get(raw_query['i'],None)
+            id = raw_query['i'] + '_' + raw_query['o'].replace('.','_')
+            if raw_query['o'] == 'plone.app.querystring.operation.selection.is':
+                if len(raw_query['v'])==1:
+                    continue
+                if selected:
+                    options = u'<option value="">All</option>'
+                else:
+                    options = u'<option selected="selected" value="">All</option>'
+                for value in raw_query['v']:
+                    is_selected = self._sel(value,selected)
+                    optstr = u'<option value="%(value)s" %(selected)s >%(name)s</option>'
+                    options += optstr % {
+                                        'value': value,
+                                        'selected': is_selected,
+                                        'name': value}
+                    input_html = u'''
+                        <select id="%s" name="%s">
+                        %s
+                        </select>''' % ( id,
+                            raw_query['i'], options)
+            elif raw_query['o']=='plone.app.querystring.operation.string.contains':
+                value = self.request.get(raw_query['i'],'')
+                input_html = u'''<input type="text"
+                            size="25"
+                            id="search-%s"
+                            name="%s"
+                            value="%s"/>''' % (id,
+                                raw_query['i'], value)
+            elif raw_query['o'] in DATERANGE_OPERATORS:
+                start_date, end_date = get_start_end_ng(self.context, query,
+                                                raw_query,
+                                                self.portal_catalog)
+                startval = self.request.get('start-' + raw_query['i'],
+                            start_date.strftime('%Y/%m/%d'))
+                endval = self.request.get('end-' + raw_query['i'],
+                            end_date.strftime('%Y/%m/%d'))
+                input_html = self._daterange_criterion(
+                        raw_query['i'], start_date, startval,
+                        end_date, endval)
+
+            elif raw_query['o']=='plone.app.querystring.operation.date.largerThanRelativeDate':
+                #within last n days
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.beforeToday':
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.lessThanRelativeDate':
+                #within next n days
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.largerThan':
+                #after date
+                import ipdb; ipdb.set_trace()
+            elif raw_query['o']=='plone.app.querystring.operation.date.today':
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.afterToday':
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.lessThan':
+                # before date
+                pass
+            elif raw_query['o']=='plone.app.querystring.operation.date.between':
+                # between date and date
+                pass
+            else:
+                continue
+
+            criterion_field = {
+                'id': raw_query['i'] + '_' + raw_query['o'].replace('.','_'),
+                'description': criterion['description'],
+                'label': criterion['title'],
+                'field': raw_query['i'],
+                'input': input_html,
+                }
+            criteria.append(criterion_field)
+        return criteria
+
 class FlexigridViewlet(BaseViewlet):
     ''' displays the flexigrid results'''
 
@@ -278,6 +383,17 @@ class ResultTableViewlet(BaseViewlet):
         results['display_legend'] = (results['num_results'] > 0)
         return results
 
+class ResultTableViewletNG(ResultTableViewlet):
+
+    def search_results(self):
+        results = get_search_results_ng(self)
+        results['fields'] = self.get_table_fields()
+        results['id'] = "topichtmlresults"
+        results['display_legend'] = (results['num_results'] > 0)
+        return results
+
+
+
 class JsViewlet(BaseViewlet):
     ''' inserts the js to render the above viewlets '''
 
@@ -292,6 +408,11 @@ class JsViewlet(BaseViewlet):
          $('#flexitopicresults').flexOptions({newp: 1}).flexReload();
         }) ;
    });
+   $('#flexitopicsearchform').find('input:radio').each(function(i) {
+     $(this).change(function( objEvent ){
+         $('#flexitopicresults').flexOptions({newp: 1}).flexReload();
+        }) ;
+   });
  });
 
     $("#flexitopicresults").flexigrid
@@ -379,25 +500,41 @@ class JsViewlet(BaseViewlet):
                 sortable='true'
             else:
                 sortable='false'
-            tl.append( t % (field['label'], field['name'], this_field_width, sortable))
+            tl.append( t % (self.context.translate(_(field['label'])),
+                        field['name'], this_field_width, sortable))
         sort = ''
-        for criterion in self.context.listCriteria():
-            if criterion.meta_type =='ATSortCriterion':
-                sortname = criterion.getCriteriaItems()[0][1]
+        if hasattr(self.context, 'listCriteria'):
+            #old style collection
+            for criterion in self.context.listCriteria():
+                if criterion.meta_type =='ATSortCriterion':
+                    sortname = criterion.getCriteriaItems()[0][1]
+                    sortorder = 'asc'
+                    if len(criterion.getCriteriaItems())==2:
+                        if criterion.getCriteriaItems()[1][1] =='reverse':
+                            sortorder = 'desc'
+                    sort = "sortname: '%s', sortorder: '%s'," % (
+                                sortname, sortorder)
+        elif hasattr(self.context, 'getSort_on'):
+            #new style collection
+            sortname = self.context.getSort_on()
+            sortorder = 'asc'
+            if self.context.getSort_reversed():
+                sortorder = 'desc'
+            else:
                 sortorder = 'asc'
-                if len(criterion.getCriteriaItems())==2:
-                    if criterion.getCriteriaItems()[1][1] =='reverse':
-                        sortorder = 'desc'
-                sort = "sortname: '%s', sortorder: '%s'," % (
-                            sortname, sortorder)
+            sort = "sortname: '%s', sortorder: '%s'," % (
+                                sortname, sortorder)
         table_name = self.context.Title()
         url = self.context.absolute_url() + '/@@flexijson_view'
-        items_ppage = self.context.getItemCount()
+        try:
+            items_ppage = self.context.getItemCount()
+        except AttributeError:
+            items_ppage = settings.items_pp
         add_form_data_js = self.add_form_data_js % self.context.absolute_url()
         if items_ppage==0:
-            items_ppage = 15
+            items_ppage = settings.items_pp
         js = self.js_template % {
-                'url':url,
+                'url': url,
                 'col_model': ', '.join(tl),
                 'sort': sort,
                 'title': table_name,
